@@ -56,6 +56,7 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
     let users = admin
         .realm_users_get(
             "test", None, None, None, None, None, None, None, None, None, None, None, None, None,
+            None,
         )
         .await?;
 
@@ -94,4 +95,7 @@ mod error;
 mod rest;
 
 pub use error::KeycloakError;
-pub use rest::{KeycloakAdmin, KeycloakAdminToken, KeycloakTokenSupplier};
+pub use rest::{
+    KeycloakAdmin, KeycloakAdminToken, KeycloakServiceAccountAdminTokenRetriever,
+    KeycloakTokenSupplier,
+};
